@@ -1,6 +1,6 @@
 package ExtUtils::Helpers;
 {
-  $ExtUtils::Helpers::VERSION = '0.019';
+  $ExtUtils::Helpers::VERSION = '0.020';
 }
 use strict;
 use warnings FATAL => 'all';
@@ -35,10 +35,10 @@ my $separator = $separator{$^O} || '::';
 sub man3_pagename {
 	my ($filename, $base) = @_;
 	$base ||= 'lib';
-	my ($vols, $dirs, $file) = splitpath(canonpath($filename));
+	my ($vols, $dirs, $file) = splitpath(canonpath(abs2rel($filename, $base)));
 	$file = basename($file, qw/.pm .pod/);
-	$dirs = abs2rel($dirs, $base);
-	return join $separator, splitdir($dirs), "$file.3pm";
+	my @dirs = grep { length } splitdir($dirs);
+	return join $separator, @dirs, "$file.3pm";
 }
 
 1;
@@ -55,7 +55,7 @@ ExtUtils::Helpers - Various portability utilities for module builders
 
 =head1 VERSION
 
-version 0.019
+version 0.020
 
 =head1 SYNOPSIS
 
